@@ -1,7 +1,7 @@
 """
 Type annotations for personalize-runtime service client.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_personalize_runtime/client.html)
+[Open documentation](./client.md)
 
 Usage::
 
@@ -16,10 +16,7 @@ from typing import Any, Dict, List, Type
 
 from botocore.client import ClientMeta
 
-from mypy_boto3_personalize_runtime.type_defs import (
-    GetPersonalizedRankingResponseTypeDef,
-    GetRecommendationsResponseTypeDef,
-)
+from .type_defs import GetPersonalizedRankingResponseTypeDef, GetRecommendationsResponseTypeDef
 
 __all__ = ("PersonalizeRuntimeClient",)
 
@@ -40,8 +37,8 @@ class Exceptions:
 
 class PersonalizeRuntimeClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/personalize-runtime.html#PersonalizeRuntime.Client)
-    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_personalize_runtime/client.html)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.74/reference/services/personalize-runtime.html#PersonalizeRuntime.Client)
+    [Show boto3-stubs documentation](./client.md)
     """
 
     meta: ClientMeta
@@ -49,8 +46,8 @@ class PersonalizeRuntimeClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.can_paginate)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_personalize_runtime/client.html#can-paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.74/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.can_paginate)
+        [Show boto3-stubs documentation](./client.md#can_paginate)
         """
 
     def generate_presigned_url(
@@ -61,8 +58,8 @@ class PersonalizeRuntimeClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_personalize_runtime/client.html#generate-presigned-url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.74/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](./client.md#generate_presigned_url)
         """
 
     def get_personalized_ranking(
@@ -75,8 +72,8 @@ class PersonalizeRuntimeClient:
         filterValues: Dict[str, str] = None,
     ) -> GetPersonalizedRankingResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.get_personalized_ranking)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_personalize_runtime/client.html#get-personalized-ranking)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.74/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.get_personalized_ranking)
+        [Show boto3-stubs documentation](./client.md#get_personalized_ranking)
         """
 
     def get_recommendations(
@@ -90,6 +87,6 @@ class PersonalizeRuntimeClient:
         filterValues: Dict[str, str] = None,
     ) -> GetRecommendationsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.get_recommendations)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_personalize_runtime/client.html#get-recommendations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.74/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.get_recommendations)
+        [Show boto3-stubs documentation](./client.md#get_recommendations)
         """
